Ariwater: Better Library Write Spider
======================================

.. start-inclusion-marker-do-not-remove

.
**Airwater** is a Python library that offers a sensible and human-friendly approach to Simply write spider, it helps you work with write spider with fewer imports and a lot less code.



Why use Arrow over built-in modules?
------------------------------------

Python's standard library and some other low-level modules have near-complete date, time and timezone functionality, but don't work very well from a usability perspective:

- Too many modules: datetime, time, calendar, dateutil, pytz and more
- Too many types: date, time, datetime, tzinfo, timedelta, relativedelta, etc.
- Timezones and timestamp conversions are verbose and unpleasant
- Timezone naivety is the norm
- Gaps in functionality: ISO-8601 parsing, timespans, humanization

Features
--------


Quick Start
-----------

Installation
~~~~~~~~~~~~


.. code-block:: console

    $ pip install -U airwater

Example Usage
~~~~~~~~~~~~~

.
Documentation
-------------

For full documentation, please visit

Contributing
------------

Contributions are welcome for both code and localizations (adding and updating locales). Begin by gaining familiarity with the Arrow library and its features. Then, jump into contributing:

